@@ -108,14 +108,9 @@ class Oauth2SessionAsync(OAuth2Session):
                 else:
                     raise
 
-        # No, we should not be using a session for every request. Yes, we are
-        # not achieving 100% performance by doing this. The benefit is that we
-        # don't require `async with OssapiAsync(...) as api:` syntax in order to
-        # use ossapi.
-        async with aiohttp.ClientSession() as session:
-            return await session.request(
-                method, url, headers=headers, data=data, **kwargs
-            )
+        return await session.request(
+            method, url, headers=headers, data=data, **kwargs
+        )
 
 # our `request` function below relies on the ordering of these types. The
 # base type must come first, with any auxiliary types that the base type accepts
